Function egress_pattern_contains
pub fn egress_pattern_contains(grant: &str, carveout: &str) -> boolExpand description
Return whether an egress grant contains every destination matched by a carveout pattern.
Both arguments must already be canonicalized by
normalize_egress_pattern. Exact grants contain only the same exact
host. A suffix grant contains exact subdomains and narrower suffix grants,
but never its apex. An exact grant can never contain a suffix grant.